function Controller() {
    function toggleWidgetList() {
        Ti.API.info("NOT IMPLEMENTED: Toggle widget list");
    }
    function toggleOptions() {
        appEnvironment.fullscreenedWidget ? appEnvironment.fullscreenedWidget.openWidgetConfig() : Ti.API.info("NOT IMPLEMENTED: Toggle app options");
    }
    function exitWidgetFullscreen() {
        $.widgetSpace.remove(appEnvironment.fullscreenedWidget.getView("fullscreen"));
        $.exitFullscreenButton.visible = false;
        $.widgetTitle.text = "ExeterConnect";
        appEnvironment.fullscreenedWidget = null;
    }
    function makeWidgetFullscreen(_widget) {
        $.widgetSpace.add(_widget.getView("fullscreen"));
        $.exitFullscreenButton.visible = true;
        $.widgetTitle.text = _widget.displayName;
        appEnvironment.fullscreenedWidget = _widget;
    }
    function getStoredAppEnvironment() {
        return JSON.parse(Ti.App.Properties.getString("appEnvironment"));
    }
    function saveAppEnvironment() {
        Ti.App.Properties.setString("appEnvironment", JSON.stringify(appEnvironment));
    }
    function setupEnvironment() {
        var storedAppEnvironment = getStoredAppEnvironment();
        var availableWidgets = [ {
            widgetName: "LionCardWidget",
            enabled: true
        }, {
            widgetName: "DailyMenuWidget",
            enabled: true
        }, {
            widgetName: "DeanOnDutyWidget",
            enabled: true
        } ];
        if (storedAppEnvironment) {
            appEnvironment = storedAppEnvironment;
            for (i = 0; availableWidgets.length > i; i++) {
                var availableWidget = availableWidgets[i];
                var alreadyHasAvailableWidget = false;
                for (j = 0; appEnvironment.configuredWidgets.length > j; j++) {
                    var currentWidget = appEnvironment.configuredWidgets[j];
                    if (availableWidget.widgetName == currentWidget.widgetName) {
                        alreadyHasAvailableWidget = true;
                        break;
                    }
                }
                alreadyHasAvailableWidget || appEnvironment.configuredWidgets.push(availableWidget);
            }
        } else {
            appEnvironment = {};
            appEnvironment.fullscreenedWidget = null;
            appEnvironment.configuredWidgets = availableWidgets;
            Ti.API.info("NOT IMPLEMENTED: Setup other environment vars");
        }
        saveAppEnvironment();
    }
    function configMenubar() {
        Ti.Platform.displayCaps.platformHeight / Ti.Platform.displayCaps.platformWidth;
        $.leftMenuItem.width = $.leftMenuItem.size.height;
        $.middleMenuItem.left = $.leftMenuItem.width;
        $.middleMenuItem.width = $.mainMenu.size.width - 2 * $.leftMenuItem.size.height;
        $.rightMenuItem.width = $.leftMenuItem.width;
        $.widgetTitle.font = {
            fontSize: Math.floor(Ti.Platform.displayCaps.platformHeight / 24),
            fontWeight: "bold"
        };
    }
    function showWelcomeScreen() {
        if (appEnvironment.econnectUsername && appEnvironment.econnectUsername.length > 0) {
            $.welcomeUsername.value = appEnvironment.econnectUsername;
            $.welcomePassword.value = appEnvironment.econnectPassword;
        }
        $.welcomeUsername.font = {
            fontSize: Math.floor(Ti.Platform.displayCaps.platformHeight / 28)
        };
        $.welcomePassword.font = {
            fontSize: Math.floor(Ti.Platform.displayCaps.platformHeight / 28)
        };
    }
    function signInToExeterConnect(_username, _password, _callback) {
        if (1 > _username.length || 1 > _password.length) {
            Ti.UI.createAlertDialog({
                title: "Sign In Error",
                message: "Please enter a username and password",
                buttonNames: [ "OK" ],
                cancel: 0
            }).show();
            _callback(false);
        } else {
            _username = _username.toLowerCase().replace("master\\", "").replace("@exeter.edu", "");
            var econnectSignInClient = Titanium.Network.createHTTPClient();
            econnectSignInClient.onerror = function() {
                econnectSignInClient = null;
                Ti.UI.createAlertDialog({
                    title: "Sign In Error",
                    message: "Sign in to Exeter Connect failed",
                    buttonNames: [ "OK" ],
                    cancel: 0
                }).show();
                _callback(false);
            };
            econnectSignInClient.onreadystatechange = function() {
                if (4 == econnectSignInClient.readyState && 302 == econnectSignInClient.status) {
                    var econnectCookie = econnectSignInClient.getResponseHeader("Set-Cookie");
                    var testEconnectCookieClient = Titanium.Network.createHTTPClient();
                    testEconnectCookieClient.onerror = function() {
                        testEconnectCookieClient = null;
                        Ti.UI.createAlertDialog({
                            title: "Sign In Error",
                            message: "Sign in to Exeter Connect failed",
                            buttonNames: [ "OK" ],
                            cancel: 0
                        }).show();
                        _callback(false);
                    };
                    testEconnectCookieClient.onreadystatechange = function() {
                        if (4 == testEconnectCookieClient.readyState && 200 == testEconnectCookieClient.status) {
                            appEnvironment.econnectCookie = "logondata=acc=0&lgn=" + _username + "@exeter.edu; " + econnectCookie;
                            appEnvironment.econnectUsername = _username;
                            appEnvironment.econnectPassword = _password;
                            saveAppEnvironment();
                            _callback(true);
                        }
                    };
                    testEconnectCookieClient.open("GET", "https://connect.exeter.edu/student/Pages/default.aspx");
                    testEconnectCookieClient.autoRedirect = false;
                    testEconnectCookieClient.setTimeout(5e3);
                    testEconnectCookieClient.setRequestHeader("cookie", econnectCookie);
                    testEconnectCookieClient.send();
                }
            };
            econnectSignInClient.open("POST", "https://connect.exeter.edu/CookieAuth.dll?Logon");
            econnectSignInClient.autoRedirect = false;
            econnectSignInClient.setTimeout(5e3);
            econnectSignInClient.send({
                curl: "Z2FstudentZ2FPagesZ2Fdefault.aspx",
                flags: "0",
                forcedownlevel: "0",
                formdir: "3",
                trusted: "4",
                username: _username + "@exeter.edu",
                password: _password,
                SubmitCreds: "Log On"
            });
        }
    }
    function welcomeSignIn() {
        signInToExeterConnect($.welcomeUsername.value, $.welcomePassword.value, function(success) {
            if (success) {
                configMenubar();
                loadWidgetScrollable();
                $.welcomeView.visible = false;
            }
        });
    }
    function loadWidgetScrollable() {
        var widgetScrollItems = [];
        for (i = 0; appEnvironment.configuredWidgets.length > i; i++) if (appEnvironment.configuredWidgets[i].enabled) {
            var widgetName = appEnvironment.configuredWidgets[i].widgetName;
            var widget;
            try {
                var widget = Alloy.createWidget(widgetName);
            } catch (e) {
                widget = null;
            }
            if (widget) {
                var widgetScrollItem = Ti.UI.createView({
                    width: "100%",
                    height: "100%",
                    top: 0
                });
                var widgetTileTitle = Ti.UI.createLabel({
                    width: "100%",
                    height: "17%",
                    top: 0,
                    color: "white",
                    textAlign: "center",
                    font: {
                        fontSize: Math.floor(Ti.Platform.displayCaps.platformHeight / 30)
                    },
                    text: widget.displayName
                });
                var widgetLiveTileWidth;
                widgetLiveTileWidth = "iphone" == Ti.Platform.osname ? "91%" : "64%";
                var widgetLiveTile = Ti.UI.createView({
                    width: widgetLiveTileWidth,
                    height: "78%",
                    top: "14%"
                });
                (function(_widgetLiveTile, _widget) {
                    _widgetLiveTile.addEventListener("click", function() {
                        makeWidgetFullscreen(_widget);
                    });
                })(widgetLiveTile, widget);
                var widgetLiveTileView = widget.getView("livetile");
                widgetLiveTileView.width = "100%";
                widgetLiveTileView.height = "100%";
                widgetLiveTile.add(widgetLiveTileView);
                widget.updateWithEnvironment(appEnvironment);
                widgetScrollItem.add(widgetTileTitle);
                widgetScrollItem.add(widgetLiveTile);
                widgetScrollItems.push(widgetScrollItem);
            }
        }
        var widgetScrollable;
        widgetScrollable = "iphone" == Ti.Platform.osname ? Ti.UI.createScrollableView({
            views: widgetScrollItems,
            clipViews: false,
            hitRect: {
                height: $.widgetHolder.size.height,
                width: $.widgetHolder.size.width,
                x: 0,
                y: 0
            },
            width: "74%",
            height: "100%"
        }) : Ti.UI.createScrollableView({
            views: widgetScrollItems,
            width: "100%",
            height: "100%"
        });
        $.widgetHolder.backgroundRepeat = true;
        $.widgetHolder.backgroundImage = "widgetHolderBackground.png";
        $.widgetHolder.add(widgetScrollable);
    }
    require("alloy/controllers/BaseController").apply(this, Array.prototype.slice.call(arguments));
    arguments[0] ? arguments[0]["__parentSymbol"] : null;
    arguments[0] ? arguments[0]["$model"] : null;
    var $ = this;
    var exports = {};
    var __defers = {};
    $.__views.index = Ti.UI.createWindow({
        id: "index"
    });
    $.__views.index && $.addTopLevelView($.__views.index);
    $.__views.mainView = Ti.UI.createView({
        width: "100%",
        height: "100%",
        top: 0,
        id: "mainView"
    });
    $.__views.index.add($.__views.mainView);
    $.__views.welcomeView = Ti.UI.createView({
        width: "100%",
        height: "100%",
        top: 0,
        backgroundImage: "welcomeViewBackground.png",
        zIndex: 10,
        id: "welcomeView"
    });
    $.__views.mainView.add($.__views.welcomeView);
    $.__views.welcomeLogo = Ti.UI.createImageView({
        width: "88%",
        height: "auto",
        top: "15%",
        image: "exeterConnectLogo.png",
        id: "welcomeLogo"
    });
    $.__views.welcomeView.add($.__views.welcomeLogo);
    $.__views.welcomeUsername = Ti.UI.createTextField({
        width: "70%",
        height: Ti.UI.SIZE,
        top: "42%",
        borderStyle: Ti.UI.INPUT_BORDERSTYLE_ROUNDED,
        textAlign: "center",
        hintText: "Username",
        color: "black",
        id: "welcomeUsername"
    });
    $.__views.welcomeView.add($.__views.welcomeUsername);
    $.__views.welcomePassword = Ti.UI.createTextField({
        width: "70%",
        height: Ti.UI.SIZE,
        top: "54%",
        borderStyle: Ti.UI.INPUT_BORDERSTYLE_ROUNDED,
        textAlign: "center",
        hintText: "Password",
        passwordMask: true,
        color: "black",
        id: "welcomePassword"
    });
    $.__views.welcomeView.add($.__views.welcomePassword);
    $.__views.welcomeSignInButton = Ti.UI.createImageView({
        width: "34%",
        height: "auto",
        top: "73%",
        image: "welcomeSignInButton.png",
        id: "welcomeSignInButton"
    });
    $.__views.welcomeView.add($.__views.welcomeSignInButton);
    welcomeSignIn ? $.__views.welcomeSignInButton.addEventListener("click", welcomeSignIn) : __defers["$.__views.welcomeSignInButton!click!welcomeSignIn"] = true;
    $.__views.loggedInView = Ti.UI.createView({
        width: "100%",
        height: "100%",
        top: 0,
        id: "loggedInView"
    });
    $.__views.mainView.add($.__views.loggedInView);
    $.__views.mainMenu = Ti.UI.createView({
        height: "12%",
        width: "100%",
        top: 0,
        backgroundImage: "menubarBackground.png",
        zIndex: 2,
        id: "mainMenu"
    });
    $.__views.loggedInView.add($.__views.mainMenu);
    $.__views.leftMenuItem = Ti.UI.createView({
        height: "90%",
        left: 0,
        top: 0,
        id: "leftMenuItem"
    });
    $.__views.mainMenu.add($.__views.leftMenuItem);
    $.__views.widgetListButton = Ti.UI.createView({
        width: "100%",
        height: "100%",
        top: 0,
        backgroundImage: "widgetListButton.png",
        id: "widgetListButton"
    });
    $.__views.leftMenuItem.add($.__views.widgetListButton);
    toggleWidgetList ? $.__views.widgetListButton.addEventListener("click", toggleWidgetList) : __defers["$.__views.widgetListButton!click!toggleWidgetList"] = true;
    $.__views.exitFullscreenButton = Ti.UI.createView({
        width: "100%",
        height: "100%",
        top: 0,
        backgroundImage: "exitFullscreenButton.png",
        visible: false,
        zIndex: 3,
        id: "exitFullscreenButton"
    });
    $.__views.leftMenuItem.add($.__views.exitFullscreenButton);
    exitWidgetFullscreen ? $.__views.exitFullscreenButton.addEventListener("click", exitWidgetFullscreen) : __defers["$.__views.exitFullscreenButton!click!exitWidgetFullscreen"] = true;
    $.__views.middleMenuItem = Ti.UI.createView({
        height: "90%",
        backgroundImage: "menubarTitleBackground.png",
        backgroundRepeat: true,
        top: 0,
        id: "middleMenuItem"
    });
    $.__views.mainMenu.add($.__views.middleMenuItem);
    $.__views.widgetTitle = Ti.UI.createLabel({
        width: "100%",
        height: "100%",
        top: 0,
        color: "white",
        textAlign: "center",
        id: "widgetTitle",
        text: "ExeterConnect"
    });
    $.__views.middleMenuItem.add($.__views.widgetTitle);
    $.__views.rightMenuItem = Ti.UI.createView({
        height: "90%",
        right: 0,
        top: 0,
        id: "rightMenuItem"
    });
    $.__views.mainMenu.add($.__views.rightMenuItem);
    $.__views.optionsButton = Ti.UI.createView({
        width: "100%",
        height: "100%",
        backgroundImage: "optionsButton.png",
        id: "optionsButton"
    });
    $.__views.rightMenuItem.add($.__views.optionsButton);
    toggleOptions ? $.__views.optionsButton.addEventListener("click", toggleOptions) : __defers["$.__views.optionsButton!click!toggleOptions"] = true;
    $.__views.widgetSpace = Ti.UI.createView({
        width: "100%",
        height: "90%",
        bottom: 0,
        id: "widgetSpace"
    });
    $.__views.loggedInView.add($.__views.widgetSpace);
    $.__views.widgetLauncher = Ti.UI.createView({
        width: "100%",
        height: "100%",
        top: 0,
        id: "widgetLauncher"
    });
    $.__views.widgetSpace.add($.__views.widgetLauncher);
    $.__views.widgetHolder = Ti.UI.createView({
        width: "100%",
        height: "85%",
        top: 0,
        id: "widgetHolder"
    });
    $.__views.widgetLauncher.add($.__views.widgetHolder);
    $.__views.bottomMenubar = Ti.UI.createView({
        width: "100%",
        height: "17%",
        bottom: 0,
        backgroundImage: "bottomMenubarBackground.png",
        zIndex: 2,
        id: "bottomMenubar"
    });
    $.__views.widgetLauncher.add($.__views.bottomMenubar);
    $.__views.studentCart = Ti.UI.createView({
        width: "100%",
        height: "91%",
        bottom: 0,
        backgroundImage: "studentCartBackground.png",
        backgroundRepeat: true,
        id: "studentCart"
    });
    $.__views.bottomMenubar.add($.__views.studentCart);
    exports.destroy = function() {};
    _.extend($, $.__views);
    var appEnvironment = null;
    setupEnvironment();
    $.index.open();
    showWelcomeScreen();
    __defers["$.__views.welcomeSignInButton!click!welcomeSignIn"] && $.__views.welcomeSignInButton.addEventListener("click", welcomeSignIn);
    __defers["$.__views.widgetListButton!click!toggleWidgetList"] && $.__views.widgetListButton.addEventListener("click", toggleWidgetList);
    __defers["$.__views.exitFullscreenButton!click!exitWidgetFullscreen"] && $.__views.exitFullscreenButton.addEventListener("click", exitWidgetFullscreen);
    __defers["$.__views.optionsButton!click!toggleOptions"] && $.__views.optionsButton.addEventListener("click", toggleOptions);
    _.extend($, exports);
}

var Alloy = require("alloy"), Backbone = Alloy.Backbone, _ = Alloy._;

module.exports = Controller;