var appEnvironment = null;

function toggleWidgetList() {
	Ti.API.info("NOT IMPLEMENTED: Toggle widget list");
}

function toggleOptions() {
	if (appEnvironment.fullscreenedWidget) {
		appEnvironment.fullscreenedWidget.openWidgetConfig();
	} else {
		Ti.API.info("NOT IMPLEMENTED: Toggle app options");
	}
}

function exitWidgetFullscreen() {
	$.widgetSpace.remove(appEnvironment.fullscreenedWidget.getView("fullscreen"));
	$.exitFullscreenButton.visible = false;
	$.widgetTitle.text = "ExeterConnect";
	appEnvironment.fullscreenedWidget = null;
}

function makeWidgetFullscreen(_widget) {
	$.widgetSpace.add(_widget.getView("fullscreen"));
	$.exitFullscreenButton.visible = true;
	$.widgetTitle.text = _widget.displayName;
	appEnvironment.fullscreenedWidget = _widget;
}

function getStoredAppEnvironment() {
	return JSON.parse(Ti.App.Properties.getString('appEnvironment'));	
}

function saveAppEnvironment() {
	Ti.App.Properties.setString('appEnvironment', JSON.stringify(appEnvironment));
}

function setupEnvironment() {
	var storedAppEnvironment = getStoredAppEnvironment();

	var availableWidgets = [{
		widgetName : "LionCardWidget",
		enabled : true
	}, {
		widgetName : "DailyMenuWidget",
		enabled : true
	},{
		widgetName : "DeanOnDutyWidget",
		enabled : true
	}];

	if (storedAppEnvironment) {
		appEnvironment = storedAppEnvironment;

		for ( i = 0; i < availableWidgets.length; i++) {
			var availableWidget = availableWidgets[i];
			var alreadyHasAvailableWidget = false;
			for ( j = 0; j < appEnvironment.configuredWidgets.length; j++) {
				var currentWidget = appEnvironment.configuredWidgets[j];
				if (availableWidget.widgetName == currentWidget.widgetName) {
					alreadyHasAvailableWidget = true;
					break;
				}
			}

			if (!alreadyHasAvailableWidget) {
				appEnvironment.configuredWidgets.push(availableWidget);
			}
		}
	} else {
		appEnvironment = {};
		appEnvironment.fullscreenedWidget = null;
		appEnvironment.configuredWidgets = availableWidgets;
		Ti.API.info("NOT IMPLEMENTED: Setup other environment vars");
	}
	
	saveAppEnvironment();
}

function configMenubar() {
	var widthToHeight = Ti.Platform.displayCaps.platformHeight / Ti.Platform.displayCaps.platformWidth;
	$.leftMenuItem.width = $.leftMenuItem.size.height;
	$.middleMenuItem.left = $.leftMenuItem.width;
	$.middleMenuItem.width = $.mainMenu.size.width - (2 * $.leftMenuItem.size.height);
	$.rightMenuItem.width = $.leftMenuItem.width;
	$.widgetTitle.font = {
		fontSize : Math.floor(Ti.Platform.displayCaps.platformHeight / 24),
		fontWeight: "bold"
	};
}

function showWelcomeScreen() {
	if (appEnvironment.econnectUsername && appEnvironment.econnectUsername.length > 0) {
		$.welcomeUsername.value = appEnvironment.econnectUsername;
		$.welcomePassword.value = appEnvironment.econnectPassword;
	}

	$.welcomeUsername.font = {
		fontSize : Math.floor(Ti.Platform.displayCaps.platformHeight / 28)
	};
	$.welcomePassword.font = {
		fontSize : Math.floor(Ti.Platform.displayCaps.platformHeight / 28)
	};
}

function signInToExeterConnect(_username, _password, _callback) {
	if (_username.length < 1 || _password.length < 1) {
		Ti.UI.createAlertDialog({
			title : "Sign In Error",
			message : "Please enter a username and password",
			buttonNames : ['OK'],
			cancel : 0
		}).show();

		_callback(false);
	} else {
		_username = _username.toLowerCase().replace("master\\", "").replace("@exeter.edu", "");

		var econnectSignInClient = Titanium.Network.createHTTPClient();

		econnectSignInClient.onerror = function(e) {
			econnectSignInClient = null;

			Ti.UI.createAlertDialog({
				title : "Sign In Error",
				message : "Sign in to Exeter Connect failed",
				buttonNames : ['OK'],
				cancel : 0
			}).show();

			_callback(false);
		};

		econnectSignInClient.onreadystatechange = function() {
			if (econnectSignInClient.readyState == 4 && econnectSignInClient.status == 302) {
				var econnectCookie = econnectSignInClient.getResponseHeader("Set-Cookie");

				var testEconnectCookieClient = Titanium.Network.createHTTPClient();

				testEconnectCookieClient.onerror = function(e) {
					testEconnectCookieClient = null;

					Ti.UI.createAlertDialog({
						title : "Sign In Error",
						message : "Sign in to Exeter Connect failed",
						buttonNames : ['OK'],
						cancel : 0
					}).show();

					_callback(false);
				}

				testEconnectCookieClient.onreadystatechange = function() {
					if (testEconnectCookieClient.readyState == 4 && testEconnectCookieClient.status == 200) {
						appEnvironment.econnectCookie = "logondata=acc=0&lgn=" + _username + "@exeter.edu; " + econnectCookie;
						appEnvironment.econnectUsername = _username;
						appEnvironment.econnectPassword = _password;
						
						saveAppEnvironment();
						
						_callback(true);
					}
				}
				testEconnectCookieClient.open("GET", "https://connect.exeter.edu/student/Pages/default.aspx");
				testEconnectCookieClient.autoRedirect = false;
				testEconnectCookieClient.setTimeout(5000);
				testEconnectCookieClient.setRequestHeader("cookie", econnectCookie);
				testEconnectCookieClient.send();
			}
		};

		econnectSignInClient.open("POST", "https://connect.exeter.edu/CookieAuth.dll?Logon");
		econnectSignInClient.autoRedirect = false;
		econnectSignInClient.setTimeout(5000);
		econnectSignInClient.send({
			curl : "Z2FstudentZ2FPagesZ2Fdefault.aspx",
			flags : "0",
			forcedownlevel : "0",
			formdir : "3",
			trusted : "4",
			username : _username + "@exeter.edu",
			password : _password,
			SubmitCreds : "Log On"
		});
	}
}

function welcomeSignIn() {
	signInToExeterConnect($.welcomeUsername.value, $.welcomePassword.value, function(success) {
		if (success) {
			configMenubar();
			loadWidgetScrollable();
			$.welcomeView.visible = false;
		}
	});
}

function loadWidgetScrollable() {
	var widgetScrollItems = [];

	for ( i = 0; i < appEnvironment.configuredWidgets.length; i++) {
		if (appEnvironment.configuredWidgets[i].enabled) {
			var widgetName = appEnvironment.configuredWidgets[i].widgetName;

			var widget;
			try {
				var widget = Alloy.createWidget(widgetName);
			} catch (e) {
				widget = null;
			}

			if (widget) {
				var widgetScrollItem = Ti.UI.createView({
					width : "100%",
					height : "100%",
					top:0
				});

				var widgetTileTitle = Ti.UI.createLabel({
					width : "100%",
					height : "17%",
					top : 0,
					color : "white",
					textAlign : 'center',
					font : {
						fontSize : Math.floor(Ti.Platform.displayCaps.platformHeight / 30)
					},
					text : widget.displayName
				});

				var widgetLiveTileWidth;

				if (Ti.Platform.osname == 'iphone') {
					widgetLiveTileWidth = "91%";
				} else {
					widgetLiveTileWidth = "64%";
				}

				var widgetLiveTile = Ti.UI.createView({
					width : widgetLiveTileWidth,
					height : "78%",
					top : "14%"
				});

				(function(_widgetLiveTile, _widget) {
					_widgetLiveTile.addEventListener('click', function(e) {
						makeWidgetFullscreen(_widget);
					});
				})(widgetLiveTile, widget);

				var widgetLiveTileView = widget.getView("livetile");
				widgetLiveTileView.width = "100%";
				widgetLiveTileView.height = "100%";
				widgetLiveTile.add(widgetLiveTileView);
				
				widget.updateWithEnvironment(appEnvironment);

				widgetScrollItem.add(widgetTileTitle);
				widgetScrollItem.add(widgetLiveTile);

				widgetScrollItems.push(widgetScrollItem);
			}
		}
	}

	var widgetScrollable;

	if (Ti.Platform.osname == 'iphone') {
		widgetScrollable = Ti.UI.createScrollableView({
			views : widgetScrollItems,
			clipViews : false,
			hitRect : {
				height : $.widgetHolder.size.height,
				width : $.widgetHolder.size.width,
				x : 0,
				y : 0
			},
			width : "74%",
			height : "100%"
		});
	} else {
		widgetScrollable = Ti.UI.createScrollableView({
			views : widgetScrollItems,
			width : "100%",
			height : "100%"
		});
	}
	
	$.widgetHolder.backgroundRepeat = true;
	$.widgetHolder.backgroundImage = "widgetHolderBackground.png";
	$.widgetHolder.add(widgetScrollable);
}

setupEnvironment();
$.index.open();
showWelcomeScreen();
